# encoding: utf-8

require_relative '../../hocon/impl'
require_relative '../../hocon/config_mergeable'

class Hocon::Impl::MergeableValue < Hocon::ConfigMergeable
  # TODO
end
